@@ -16,11 +16,12 @@ FORT_TEXT_REPLACEMENTS = {
 # Keep all comment lines and all lines from a file that start with the
 # following expressions (the file is converted to all upper case).
 ACCEPTABLE_LINE_STARTS = {'ABSTRACT', 'CHARACTER', 'END', # 'EXTERNAL',
-                          'FUNCTION', 'IMPLICIT', 'INTEGER',
-                          'INTERFACE', 'LOGICAL', 'MODULE',
+                          'INTEGER', 'LOGICAL', 'REAL', 'COMPLEX',
+                          'IMPLICIT', 'INTERFACE', 'MODULE', 'FUNCTION',
                           'OPTIONAL', 'PRIVATE', 'PROCEDURE',
-                          'PUBLIC', 'PURE', 'REAL', 'RECURSIVE',
+                          'PUBLIC', 'PURE', 'RECURSIVE',
                           'SUBROUTINE', 'TYPE', 'USE'}
+LINE_STARTS_TO_REMOVE = {'PURE', 'RECURSIVE'}
 
 # Immediately exclude a file from automatic compilation if it has a
 # line starting with the following.
@@ -166,8 +167,9 @@ def parse_argument(list_of_lines, comments, parent):
     from .real import Real
     from .integer import Integer
     from .logical import Logical
+    from .complex import Complex
     from .type import TypeArgument
-    for arg_type in [Real, Integer, Logical, TypeArgument]:
+    for arg_type in [Real, Integer, Logical, Complex, TypeArgument]:
         if (line[0] == arg_type.type):
             success = True
             break
@@ -189,7 +191,7 @@ def parse_argument(list_of_lines, comments, parent):
             # Check to see of there is a paranthetical group after
             #   the arugment type (this would be for a KIND).
             kind, tail = pop_group(line[1:], open_with="(", close_with=")")
-            base = line[0] + ["("] + kind + [")"]
+            base = [line[0]] + ["("] + kind + [")"]
         else:
             base = line[:1]
             tail = line[1:]
@@ -211,7 +213,7 @@ def parse_argument(list_of_lines, comments, parent):
         #  after the name. There will only be other arguments after
         #  this one if there is a "," in the line. If no "," then stop.
         elif (tail[0] == "="):
-            if ("," in tail):
+            if (("," in tail) and ("=" in tail[1:])):
                 tail = tail[tail.index(",")+1:]
             else: break
         # Finally, if it is not a comma, group, or value, it must be an argument name.
