@@ -3,7 +3,7 @@ from .argument import Argument
 class Logical(Argument):
     type = "LOGICAL"
     c_types = {"4":"ctypes.c_bool"}
-    default_singleton = 1
+    default_singleton = "0"
 
     # Add a warning that 
     def __init__(self, *args, **kwargs):
@@ -11,7 +11,7 @@ class Logical(Argument):
         if (self.dimension is not None):
             # Change the C-type of this Logical to be an "int" for arrays.
             self.c_types = self.c_types.copy()
-            self.c_types["4"] = "int"
+            self.c_types["4"] = "ctypes.c_int"
             # Show a warning to the user.
             from fmodpy.config import show_warnings
             if show_warnings:
